@@ -26,7 +26,7 @@ async def exception_handler(
     logger.exception(exception)
 
     await broker.publish(
-        ErrorMessage(message=str(exception), routing_key=routing_key),
+        ErrorMessage(message=str(exception).split("\n"), routing_key=routing_key),
         routing_key=f"error.{name}",
         exchange=account_exchange,
         correlation_id=correlation_id,
