@@ -11,8 +11,24 @@ from cattle_grid.database.account import Account
 from cattle_grid.manage import AccountManager
 
 
-def protocol_and_backend():
-    protocol = NameAndVersion(name="CattleDrive", version="0.1.0")
+def cattle_drive_version():
+    """
+    Gives the current cattle drive version
+
+    ```python
+    >>> print(cattle_drive_version().model_dump_json(indent=2))
+    {
+      "name": "CattleDrive",
+      "version": "0.1.1"
+    }
+
+    ```
+    """
+    return NameAndVersion(name="CattleDrive", version="0.1.1")
+
+
+def protocol_and_backend() -> dict[str, NameAndVersion]:
+    protocol = cattle_drive_version()
     backend = NameAndVersion(name="cattle_grid", version=__version__)
 
     return dict(protocol=protocol, backend=backend)
