@@ -26,7 +26,9 @@ def create_processing_router(exchange: RabbitExchange | None = None) -> RabbitRo
     ]
     for routing_key, coroutine in routing_config:
         router.subscriber(
-            RabbitQueue(f"cg_internal_{routing_key}", routing_key=routing_key),
+            RabbitQueue(
+                f"cg_internal_{routing_key}", routing_key=routing_key, durable=True
+            ),
             exchange=exchange,
             title=f"Internal:{routing_key}",
         )(coroutine)
