@@ -100,6 +100,9 @@ async def verify_signature(
     """
     headers = MutableHeaders(request.headers)
 
+    logger.debug("Got auth request with headers:")
+    logger.debug(headers)
+
     if "signature" not in headers:
         if ContentType.html in servable_content_types:
             response.headers["x-cattle-grid-should-serve"] = "html"
