@@ -15,7 +15,7 @@ from .globals import (
 )
 
 
-Transformer = Annotated[Callable[[dict], Awaitable[dict]], Depends(get_transformer)]
+Transformer = Annotated[Callable[..., Awaitable[dict]], Depends(get_transformer)]
 """The transformer loaded from extensions"""
 
 LookupAnnotation = Annotated[LookupMethod, Depends(get_lookup)]
