@@ -1,4 +1,3 @@
-from faststream.rabbit import RabbitBroker
 from faststream import ExceptionMiddleware, Context
 
 import logging
@@ -6,7 +5,7 @@ import json
 
 from cattle_grid.account.account import account_for_actor
 from cattle_grid.model.account import ErrorMessage
-from cattle_grid.dependencies import CorrelationId, AccountExchange, SqlSession
+from cattle_grid.dependencies import AccountExchangePublisher, SqlSession
 from cattle_grid.dependencies.processing import RoutingKey
 
 logger = logging.getLogger(__name__)
@@ -18,12 +17,12 @@ exception_middleware = ExceptionMiddleware()
 async def exception_handler(
     exception: Exception,
     routing_key: RoutingKey,
-    correlation_id: CorrelationId,
     session: SqlSession,
-    account_exchange: AccountExchange,
+    publisher: AccountExchangePublisher,
     message=Context("message.body"),
-    broker: RabbitBroker = Context(),
 ):
+    """When an exception occurs in processing, this handler will create
+    an appropriate entry in `receive.NAME.error` in the account exchange"""
     try:
         data = json.loads(message)
         actor_id = data["actor"]
@@ -33,17 +32,15 @@ async def exception_handler(
         return
 
     logger.info("Exception for %s", actor_id)
-
+    logger.debug(exception)
     account = await account_for_actor(session, actor_id)
     if not account:
         return
     name = account.name
 
-    logger.error("Processing error occurred in exchange for account %s", name)
+    logger.info("Processing error occurred in exchange for account %s", name)
 
-    await broker.publish(
-        ErrorMessage(message=str(exception), routing_key=routing_key),
+    await publisher(
+        ErrorMessage(message=str(exception).split("\n"), routing_key=routing_key),
         routing_key=f"error.{name}",
-        exchange=account_exchange,
-        correlation_id=correlation_id,
     )
