@@ -6,7 +6,7 @@ from contextlib import AbstractAsyncContextManager
 from pydantic import BaseModel
 from fast_depends import Depends
 
-from faststream.rabbit import RabbitRouter
+from faststream.rabbit import RabbitRouter, RabbitQueue
 from fastapi import APIRouter, Depends as FastAPIDepends
 
 from cattle_grid.model.lookup import Lookup
@@ -151,7 +151,13 @@ class Extension:
                 self.activity_router = RabbitRouter()
 
             self.activity_router.subscriber(
-                routing_key, exchange=global_container.exchange, title=routing_key
+                RabbitQueue(
+                    self.name.replace(" ", "_") + "_" + routing_key,
+                    routing_key=routing_key,
+                    durable=True,
+                ),
+                exchange=global_container.exchange,
+                title=routing_key,
             )(func)
 
             if not skip_method_information(routing_key):
