@@ -3,6 +3,7 @@
 <div class="grid cards" markdown>
 
 - [:material-api:{ .lg .middle } __OpenAPI__](../assets/redoc.html?url=openapi_simple_html_display.json)
+- [:material-file-code:{ .lg .middle } __Source__](https://codeberg.org/bovine/cattle_grid/src/branch/main/cattle_grid/extensions/examples/html_display)
 
 </div>
 
@@ -25,12 +26,17 @@ This is not an independent solution. It relies on both the [context](./context.m
 [simple_storage](./simple_storage.md) extension of cattle_grid.
 """
 
+import json
 import logging
 from uuid import uuid4
 
 from bovine.activitystreams.utils import is_public
 from sqlalchemy import select
 
+from muck_out.cattle_grid import ParsedActivity
+from muck_out.types import Object
+from uuid6 import uuid7
+
 from cattle_grid.account.account import account_for_actor
 from cattle_grid.dependencies import (
     AccountExchangePublisher,
@@ -40,8 +46,7 @@ from cattle_grid.dependencies import (
 )
 from cattle_grid.dependencies.processing import FactoriesForActor
 
-from cattle_grid.extensions import Extension
-from cattle_grid.extensions.util import lifespan_for_sql_alchemy_base_class
+from cattle_grid.extensions.examples.html_display.storage import object_for_object_id
 from cattle_grid.manage.actor import ActorManager
 from cattle_grid.model import ActivityMessage
 from cattle_grid.model.exchange import UpdateActorMessage
@@ -51,27 +56,19 @@ from cattle_grid.activity_pub.activity import actor_deletes_themselves
 from .dependencies import PublishingActor
 from .publisher import Publisher
 
-from .config import HtmlDisplayConfiguration
 from .database import (
-    Base,
     ExportPermission,
     PublishedObject,
+    PublishedObjectInteraction,
     PublishingActor as DBPublishingActor,
 )
 from .router import router
-from .types import ExportTokenResponse, NameActorMessage
-
+from .types import ExportTokenResponse, InteractionType, NameActorMessage
+from .extension_declaration import extension
 
 logger = logging.getLogger(__name__)
 
-extension = Extension(
-    name="simple html display",
-    module=__name__,
-    lifespan=lifespan_for_sql_alchemy_base_class(Base),
-    config_class=HtmlDisplayConfiguration,
-)
-extension.rewrite_group_name = "html_display"
-extension.rewrite_rules = {"publish_object": "html_display_publish_object"}
+
 extension.include_router(router)
 
 
@@ -100,12 +97,14 @@ async def html_publish_object(
     if obj.get("attributedTo") != message.actor:
         raise ValueError("Actor must match object attributedTo")
 
-    publisher = Publisher(actor, config)
-    publisher.update_object(obj)
+    publisher = Publisher(actor, config, obj)
+    session.add(
+        PublishedObject(
+            id=publisher.uuid, data=publisher.object_for_store, actor=actor.actor
+        )
+    )
 
-    session.add(PublishedObject(id=publisher.uuid, data=obj, actor=actor.actor))
-
-    activity = factories[0].create(obj).build()
+    activity = factories[0].create(publisher.object_for_remote).build()
 
     await activity_publisher(
         ActivityMessage(actor=message.actor, data=activity),
@@ -121,7 +120,7 @@ async def name_actor(
     activity_publisher: ActivityExchangePublisher,
     config: extension.Config,  # type:ignore
 ):
-    """Sets the display name of the acotr"""
+    """Sets the display name of the actor"""
     if message.actor != actor.actor:
         raise Exception("Actor mismatch")
 
@@ -181,6 +180,7 @@ async def outgoing_delete(
     message: ActivityMessage,
     session: SqlSession,
 ):
+    """Deletes the publishing actor, if they delete themself"""
     activity = message.data.get("raw")
     if not isinstance(activity, dict):
         return
@@ -197,3 +197,87 @@ async def outgoing_delete(
 
     await session.delete(actor)
     await session.flush()
+
+
+@extension.subscribe("incoming.Like")
+async def html_display_incoming_like(
+    activity: ParsedActivity,
+    message: ActivityMessage,
+    session: CommittingSession,
+):
+    """Handles likes"""
+    if activity is None:
+        logger.info("Unparsed like: " + json.dumps(message.data, indent=2))
+        return
+    object_id = activity.object
+
+    if not isinstance(object_id, str):
+        return
+
+    published_object = await object_for_object_id(session, object_id)
+
+    session.add(
+        PublishedObjectInteraction(
+            id=uuid7(),
+            published_object=published_object,
+            object_id=activity.id,
+            interaction=InteractionType.likes,
+        )
+    )
+
+
+@extension.subscribe("incoming.Announce")
+async def html_display_incoming_announce(
+    activity: ParsedActivity,
+    message: ActivityMessage,
+    session: CommittingSession,
+):
+    """Handles announces"""
+    if activity is None:
+        logger.info("Unparsed announce: " + json.dumps(message.data, indent=2))
+        return
+    object_id = activity.object
+
+    if not isinstance(object_id, str):
+        return
+
+    published_object = await object_for_object_id(session, object_id)
+
+    session.add(
+        PublishedObjectInteraction(
+            id=uuid7(),
+            published_object=published_object,
+            object_id=activity.id,
+            interaction=InteractionType.shares,
+        )
+    )
+
+
+@extension.subscribe("incoming.Create")
+async def html_display_incoming_create(
+    message: ActivityMessage,
+    session: CommittingSession,
+):
+    """Handles replies"""
+    logger.info(message.data)
+    embedded_object = Object.model_validate(
+        message.data.get("parsed", {}).get("embeddedObject")
+    )
+    if embedded_object is None:
+        logger.info("Unparsed create: " + json.dumps(message.data, indent=2))
+        return
+    object_id = embedded_object.in_reply_to
+
+    if not isinstance(object_id, str):
+        return
+
+    published_object = await object_for_object_id(session, object_id)
+
+    session.add(
+        PublishedObjectInteraction(
+            id=uuid7(),
+            published_object=published_object,
+            object_id=embedded_object.id,
+            interaction=InteractionType.replies,
+        )
+    )
