@@ -5,7 +5,7 @@ from cattle_grid.dependencies import CommittingSession
 from cattle_grid.dependencies.processing import MessageActor
 
 from .storage import publishing_actor_for_actor_id
-from .models import PublishingActor as PublishingActorModel
+from .database import PublishingActor as PublishingActorModel
 
 
 async def publishing_actor(session: CommittingSession, actor: MessageActor):
