@@ -44,6 +44,34 @@ PublishedObjectForUUID = Annotated[PublishedObject, Depends(published_object)]
 """Returns the published object"""
 
 
+async def published_object_With_interactions(session: SqlSession, uuid: uuid.UUID):
+    obj = await session.scalar(
+        select(PublishedObject)
+        .where(PublishedObject.id == uuid)
+        .options(joinedload(PublishedObject.interactions))
+    )
+    if not obj:
+        logger.info("Could not find object for id %s", str(uuid))
+        raise HTTPException(404)
+
+    return obj
+
+
+PublishedObjectWithInteractionsForUUID = Annotated[
+    PublishedObject, Depends(published_object_With_interactions)
+]
+"""Returns the published object, joined with the interactions, i.e.
+
+```python
+async def func(obj: PublishedObjectWithInteractionsForUUID):
+    for x in obj.interactions:
+        print(x)
+```
+
+is valid pseudo code.
+"""
+
+
 async def get_actor(
     session: SqlSession, publishing_actor: PublishingActorForName
 ) -> Actor:
