@@ -1,4 +1,5 @@
 from dataclasses import dataclass, field
+from typing import Any
 from uuid import UUID
 
 from bovine.activitystreams.utils import as_list
@@ -15,12 +16,35 @@ class Publisher:
 
     actor: PublishingActor
     config: HtmlDisplayConfiguration
+    obj: dict[str, Any]
     uuid: UUID = field(default_factory=uuid7)
 
-    def update_object(self, obj):
-        obj_id = self.config.url_start(self.actor.actor) + str(self.uuid)
-        obj["id"] = obj_id
-        self._add_url_to_obj(obj)
+    def __post_init__(self):
+        if "id" in self.obj:
+            obj_id = self.obj["id"]
+            self.uuid = UUID(obj_id.split("/")[-1])
+        else:
+            self.obj = {
+                **self.obj,
+                "id": self.config.url_start(self.actor.actor) + str(self.uuid),
+            }
+
+    @property
+    def object_for_store(self):
+        return self.obj
+
+    @property
+    def object_for_remote(self):
+        copy = {**self.obj}
+        copy.update(self._collection_links())
+        return self._add_url_to_obj(copy)
+
+    def _collection_links(self):
+        object_id = self.obj["id"]
+        return {
+            collection: f"{object_id}/{collection}"
+            for collection in ["replies", "shares", "likes"]
+        }
 
     def _add_url_to_obj(self, obj: dict):
         url_list = as_list(obj.get("url", []))
@@ -34,6 +58,8 @@ class Publisher:
 
         obj["url"] = url_list + [self.create_html_link(url)]
 
+        return obj
+
     def create_html_link(self, url: str | None = None):
         if url is None:
             url = self.actor.actor_id + "#html"
