@@ -1,3 +1,4 @@
+import logging
 from uuid import UUID
 from bovine.activitystreams import OrderedCollection
 import jinja2
@@ -7,13 +8,18 @@ from fastapi import APIRouter, HTTPException, Request
 from fastapi.responses import HTMLResponse, RedirectResponse
 from sqlalchemy import select
 
+from muck_out.transform.utils import sanitize_html
+
 from cattle_grid.activity_pub import is_valid_requester_for_obj
 from cattle_grid.dependencies.fastapi import SqlSession
 from cattle_grid.extensions.examples.html_display.format import format_actor_profile
 from cattle_grid.extensions.examples.html_display.database import (
     ExportPermission,
     PublishedObject,
+    PublishingActor,
 )
+from cattle_grid.extensions.examples.html_display.publisher import Publisher
+from cattle_grid.extensions.examples.html_display.types import InteractionType
 from cattle_grid.tools.fastapi import (
     ActivityPubHeaders,
     ActivityResponse,
@@ -21,11 +27,17 @@ from cattle_grid.tools.fastapi import (
     ContentType,
 )
 
+from cattle_grid.version import __version__
+
 from .fastapi_dependencies import (
     ActorProfile,
     PublishedObjectForUUID,
+    PublishedObjectWithInteractionsForUUID,
     PublishingActorForName,
 )
+from .extension_declaration import extension
+
+logger = logging.getLogger(__name__)
 
 templates = Jinja2Templates(
     env=jinja2.Environment(auto_reload=True, loader=jinja2.PackageLoader(__name__)),
@@ -41,21 +53,66 @@ async def get_index():
 
 
 @router.get("/object/{uuid}", response_class=ActivityResponse, tags=["activity_pub"])
-async def get__object(
+async def get_object(
     obj: PublishedObjectForUUID,
     ap_headers: ActivityPubHeaders,
     session: SqlSession,
+    config: extension.ConfigFastAPI,  # type:ignore
 ):
     """Returns the stored object"""
     if not ap_headers.x_cattle_grid_requester:
         raise HTTPException(401)
 
+    if ap_headers.x_ap_location != obj.data.get("id"):
+        raise HTTPException(404)
+
     if not await is_valid_requester_for_obj(
         session, ap_headers.x_cattle_grid_requester, obj.data
     ):
         raise HTTPException(401)
 
-    return obj.data
+    actor = await session.scalar(
+        select(PublishingActor).where(PublishingActor.actor == obj.actor)
+    )
+    if actor is None:
+        raise HTTPException(404)
+
+    publisher = Publisher(actor, config, obj=obj.data)
+
+    return publisher.object_for_remote
+
+
+@router.get(
+    "/object/{uuid}/{interaction}",
+    response_class=ActivityResponse,
+    tags=["activity_pub"],
+)
+async def get_object_interaction(
+    obj: PublishedObjectWithInteractionsForUUID,
+    ap_headers: ActivityPubHeaders,
+    session: SqlSession,
+    interaction: InteractionType,
+):
+    """Returns the stored object"""
+    if not ap_headers.x_cattle_grid_requester:
+        raise HTTPException(401)
+
+    collection_id = f"{obj.data.get('id')}/{interaction}"
+
+    if ap_headers.x_ap_location != collection_id:
+        raise HTTPException(404)
+
+    if not await is_valid_requester_for_obj(
+        session, ap_headers.x_cattle_grid_requester, obj.data
+    ):
+        raise HTTPException(401)
+
+    logger.info(obj.interactions)
+
+    return OrderedCollection(
+        id=collection_id,
+        items=[x.object_id for x in obj.interactions if x.interaction == interaction],
+    ).build()
 
 
 @router.get("/html/{actor_name}", response_class=HTMLResponse, tags=["html"])
@@ -84,7 +141,7 @@ async def get_actor_html(
 
     posts = [
         {
-            "body": x.data.get("content"),
+            "body": sanitize_html(x.data.get("content")),
             "date": x.data.get("published"),
             "id": str(x.id),
         }
@@ -98,6 +155,7 @@ async def get_actor_html(
             "name": actor.name,
             "profile": format_actor_profile(profile),
             "posts": posts,
+            "version": __version__,
         },
     )
 
@@ -138,7 +196,7 @@ async def export_objects(
 )
 async def get_object_html(
     actor: PublishingActorForName,
-    obj: PublishedObjectForUUID,
+    obj: PublishedObjectWithInteractionsForUUID,
     request: Request,
     should_serve: ShouldServe,
 ):
@@ -152,8 +210,24 @@ async def get_object_html(
     ):
         return RedirectResponse(obj.data["id"])
 
+    interactions = {
+        str(interaction): [
+            x.object_id for x in obj.interactions if x.interaction == interaction
+        ]
+        for interaction in [
+            InteractionType.shares,
+            InteractionType.likes,
+            InteractionType.replies,
+        ]
+    }
+
     return templates.TemplateResponse(
         request,
-        name="object.html",
-        context={"name": actor.name, "content": obj.data["content"]},
+        name="object.html.j2",
+        context={
+            "name": actor.name,
+            "content": sanitize_html(obj.data["content"]),
+            **interactions,
+            "version": __version__,
+        },
     )
