@@ -1,12 +1,18 @@
+import logging
 import random
 import string
-import uuid
-
+from uuid import UUID
 
 from sqlalchemy import select
 from sqlalchemy.ext.asyncio import AsyncSession
 
-from cattle_grid.extensions.examples.html_display.database import PublishingActor
+from cattle_grid.extensions.examples.html_display.database import (
+    PublishedObject,
+    PublishingActor,
+)
+
+
+logger = logging.getLogger(__name__)
 
 
 def new_name():
@@ -25,5 +31,14 @@ async def publishing_actor_for_actor_id(session: AsyncSession, actor_id: str):
     return actor
 
 
-async def object_for_name_and_uuid(session: AsyncSession, name: str, uuid: uuid.UUID):
-    return None
+async def object_for_object_id(
+    session: AsyncSession, object_id: str
+) -> PublishedObject | None:
+    try:
+        object_uuid = UUID(object_id.split("/")[-1])
+    except Exception:
+        return None
+
+    return await session.scalar(
+        select(PublishedObject).where(PublishedObject.id == object_uuid)
+    )
