@@ -1,3 +1,4 @@
+from enum import StrEnum, auto
 from pydantic import Field
 from cattle_grid.model.common import WithActor
 
@@ -15,3 +16,9 @@ class ExportTokenResponse(WithActor):
     export_url: str = Field(
         description="Url including the token the export is located at"
     )
+
+
+class InteractionType(StrEnum):
+    replies = auto()
+    likes = auto()
+    shares = auto()
