@@ -26,7 +26,7 @@ def check_response_status_code(context, status_code):
     assert context.response.status == int(status_code)
 
 
-@then("The response is a webpage")
+@then("The response is a webpage")  # type: ignore
 def response_is_webpage(context):
     print(context.response)
 
